@@ -2,7 +2,7 @@
 
 
 # pyswip -- Python SWI-Prolog bridge
-# Copyright (c) 2007-2012 Yüce Tekol
+# Copyright (c) 2007-2018 Yüce Tekol
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -22,9 +22,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+from __future__ import print_function
 
 import os
-import re
 import sys
 import glob
 import warnings
@@ -157,6 +157,8 @@ def _findSwiplFromExec():
 
 
 def _findSwiplWin():
+    import re
+
     """
     This function uses several heuristics to gues where SWI-Prolog is installed
     in Windows. It always returns None as the path of the resource file because,
@@ -201,7 +203,7 @@ def _findSwiplWin():
         #    home        REG_SZ  C:\Program Files\pl
         # (Note: spaces may be \t or spaces in the output)
         ret = ret[0].splitlines()
-        ret = [line for line in ret if len(line) > 0]
+        ret = [line.decode("utf-8") for line in ret if len(line) > 0]
         pattern = re.compile('[^h]*home[^R]*REG_SZ( |\t)*(.*)$')
         match = pattern.match(ret[-1])
         if match is not None:
@@ -302,9 +304,10 @@ def walk(path, name):
 
 
 def get_swi_ver():
-    swi_ver = raw_input(
+    import re
+    swi_ver = input(
                 'Please enter you SWI-Prolog version in format "X.Y.Z": ')
-    match = re.match(r'[0-9]\.[0-9]\.[0-9]')
+    match = re.search(r'[0-9]\.[0-9]\.[0-9]')
     if match is None:
         raise InputError('Error, type normal version')
     
@@ -568,7 +571,7 @@ _fixWindowsPath(_path)
 
 
 # Load the library
-_lib = CDLL(_path)
+_lib = CDLL(_path, mode=RTLD_GLOBAL)
 
 # PySWIP constants
 PYSWIP_MAXSTR = 1024
@@ -792,15 +795,8 @@ PL_get_atom_chars.restype = c_int
 
 PL_get_atom_chars = check_strings(None, 1)(PL_get_atom_chars)
 
-##define PL_get_string_chars(t, s, l) PL_get_string(t,s,l)
-#                                       /* PL_get_string() is depricated */
-#PL_EXPORT(int)         PL_get_string(term_t t, char **s, size_t *len);
-PL_get_string = _lib.PL_get_string
-
-PL_get_string = check_strings(None, 1)(PL_get_string)
-
-PL_get_string_chars = PL_get_string
-#PL_get_string_chars.argtypes = [term_t, POINTER(c_char_p), c_int_p]
+PL_get_string_chars = _lib.PL_get_string
+PL_get_string_chars.argtypes = [term_t, POINTER(c_char_p), c_int_p]
 
 #PL_EXPORT(int)         PL_get_chars(term_t t, char **s, unsigned int flags);
 PL_get_chars = _lib.PL_get_chars  # FIXME:
